@@ -1,4 +1,5 @@
 import warnings
+import win32com.client
 
 current_python_version = None
 
@@ -27,7 +28,8 @@ except ImportError:
 
 def variables():
     if current_python_version == PYTHON2:
-        return scalalib.sharedvars().__dict__
+        _player = win32com.client.Dispatch('ScalaPlayer.ScalaPlayer.1')
+        return list(_player.GetScalaScriptValue())
     elif current_python_version == PYTHON3:
         return scalascript.variables()
     elif current_python_version == PYTHON3_MAIN:
